
<div class="govuk-panel govuk-panel--confirmation">
    {% if confirm_title %}<h1 class="govuk-panel__title">{{ confirm_title }}</h1>{% endif %}
    {% if confirm_body %}<div class="govuk-panel__body">{{ confirm_body }}</div>{% endif %}
</div>
